import { MethodNames } from "./types";
export declare class RpcChannel {
    protected services: Map<string, {
        instance: any;
        methods: Set<string>;
    }>;
    private targetWindow;
    private targetOrigin;
    private pendingRequests;
    private eventHandlers;
    private messageSubject;
    constructor(targetWindow: Window, targetOrigin: string);
    private isValidEvent;
    private onMessage;
    /**
     * Calls a remote method and returns a Promise with the result.
     * @param method The name of the remote method to call (e.g., "ServiceName.methodName").
     * @param params Parameters to pass to the remote method.
     */
    call(method: string, ...params: any[]): Promise<any>;
    /**
     * Creates a proxy object to call methods on the remote service.
     * @param serviceName The name of the remote service.
     * @param methods An array of method names to expose.
     */
    getService<TService>(serviceName: string, methods: Array<MethodNames<TService>>): TService;
    /**
     * Emits an event to the remote side.
     * @param eventName The name of the event.
     * @param payload The data to send with the event.
     */
    emit(eventName: string, payload: any): void;
    /**
     * Subscribes to an event emitted by the remote side.
     * @param eventName The name of the event.
     * @param handler The function to execute when the event is received.
     */
    on(eventName: string, handler: Function): void;
    /**
     * Unsubscribes from a previously subscribed event.
     * @param eventName The name of the event.
     * @param handler The handler function to remove.
     */
    off(eventName: string, handler: Function): void;
    private generateUniqueId;
}
