import { RichTextEditorToolFunction } from "./interfaces";
/**
 * Registers a custom tool for the Rich Text Editor.
 *
 * @param {string} toolName - The name of the custom tool to register.
 * @param {RichTextEditorToolFunction} fn - The function that implements the custom tool's functionality.
 * @returns {void} This function does not return anything.
 */
export declare function registerCustomTool(toolName: string, fn: RichTextEditorToolFunction): void;
/**
 * Registers a custom callback function to set up tool icons for the rich text editor in Sitefinity.
 *
 * This function assigns a user-provided callback to the global `SfWindow` object's `rteToolsIconsSetupCallback` property.
 * The callback is responsible for configuring the icons of the rich text editor tools, ensuring they are properly displayed in the editor's toolbar.
 *
 * @param callback - A function that sets up the icons for the rich text editor tools. This function will be executed during the editor's initialization process to configure the tool icons.
 */
export declare function registerToolIcons(callback: () => void): void;
